@@ -8,7 +8,7 @@ import argparse
 
 class GenXML():
     def __init__(self, path, outputpath, is_server=None, path_type = 'all'):
-        self.path = path #goxceed_path
+        self.path = path #doc_path
         self.outputpath = outputpath
         if not os.path.exists(self.outputpath):
             os.system('mkdir -p '  + self.outputpath)
@@ -71,10 +71,16 @@ class GenXML():
             os.chdir(cfgdir)
             targetdir = re.sub(self.path, xmlpath, cfgdir)
             #if self.path_type == "all":
-            if os.path.basename(targetdir) == 'doc':
-                targetdir = re.sub('doc', '', targetdir)
-            else:
-                targetdir = re.sub('doc/', '', targetdir)
+            #if os.path.basename(targetdir) == 'doc':
+            #    #targetdir = re.sub('doc', '', targetdir)
+            #else:
+            #    targetdir = re.sub('doc/', '', targetdir)
+            tmp = targetdir.split('/')
+            new_tmp = []
+            for i in tmp:
+                if not i == 'doc':
+                    new_tmp.append(i)
+            targetdir = '/'.join(new_tmp)
             if not os.path.exists(targetdir):
                 os.makedirs(targetdir)
             targetdir = re.sub('/', '\/', targetdir)
@@ -100,7 +106,9 @@ class GenXML():
         config_dirs = []
         if self.path_type == 'all':
             for module, docpath in self.available_paths.items():
+                print(module, docpath)
                 cfgdirs = self.getmodulexml(docpath)
+                print(cfgdirs)
                 if not cfgdirs:
                     continue
                 config_dirs.extend(cfgdirs)
@@ -112,17 +120,18 @@ class GenXML():
 #doxybook -i xml -o book/solutiontest -s book/SUMMARY.md -t gitbook
 class GenMD():
     def __init__(self, start_path, bookpath, source_paths, xmlpath, \
-            path_type = 'all', link_path = '', now_dir = '', rel_path = ''):
+            path_type = 'all', link_path = '', now_dir = '', rel_path = '', enable_include_link = False):
         self.bookpath = bookpath
         self.source_paths = source_paths
         self.xmlpath = xmlpath
-        self.start_path = start_path #goxceed_path
+        self.start_path = start_path #doc_path
         self.path_type = path_type
         self.link_path = link_path
         self.exec_dir = now_dir
         self.rel_path = rel_path
+        self.enable_include_link = enable_include_link
         if self.link_path.startswith('/opt/'):
-            self.tmp_link_path = '/'.join(self.link_path.strip('/').split('/')[1:])
+            self.tmp_link_path = '/' + '/'.join(self.link_path.strip('/').split('/')[1:])
 
     def _check_path(self):
         if not os.path.exists(self.bookpath):
@@ -139,10 +148,16 @@ class GenMD():
         #targetdir = re.sub(self.start_path,'',path)
         targetdir = os.path.relpath(path, self.start_path)
         #if self.path_type == "all":
-        if os.path.basename(path) == 'doc':
-            targetdir = re.sub('doc','',targetdir)
-        else:
-            targetdir = re.sub('doc/','',targetdir)
+        #if os.path.basename(path) == 'doc':
+        #    targetdir = re.sub('doc','',targetdir)
+        #else:
+        #    targetdir = re.sub('doc/','',targetdir)
+        tmp = targetdir.split('/')
+        new_tmp = []
+        for i in tmp:
+            if not i == 'doc':
+                new_tmp.append(i)
+        targetdir = '/'.join(new_tmp)
         targetdir = targetdir.strip("/")
         mdfiles = os.listdir(path)
         if not os.path.exists(os.path.join(self.bookpath, targetdir)):
@@ -241,7 +256,6 @@ class GenMD():
                     md_dict[path_msg]['files'] = other_md_files
             self._touch_summary(md_dict)
             self._touch_readme()
-        #sys.exit()
 
     def GenMD(self, is_all):
         self.before_work()
@@ -249,13 +263,19 @@ class GenMD():
             cmd = "doxybook -i " + self.xmlpath + " -o " + self.bookpath + ' -s ' + \
                 self.bookpath + '/SUMMARY.md -t gitbook -a ' + is_all
         elif self.path_type == 'part':
+            if self.enable_include_link:
+                if self.link_path.startswith('/opt/'):
+                    docref_path = os.path.join(self.tmp_link_path, self.rel_path)
+                else:
+                    docref_path = os.path.join(self.link_path, self.rel_path)
+            else:
+                docref_path = self.rel_path
             cmd = "doxybook -i " + self.xmlpath + " -o " + self.bookpath + ' -s ' + \
-                self.bookpath + '/SUMMARY.md -t gitbook -a ' + is_all + ' -n'
+                self.bookpath + '/SUMMARY.md -t gitbook -a ' + is_all + ' -p part -l ' + docref_path
         os.system(cmd)
         #for cfgdir in self.source_paths:
         #    self.copymdfile(cfgdir)
         self.copymdfile(self.start_path)
-        #self.after_work()
 
     def check_file(self, file_name):
         #if os.path.exists(os.path.join(self.exec_dir, self.link_path, \
@@ -326,6 +346,9 @@ def parse_options():
     parser.add_argument('-d', '--dir',
         help='Path of module',
     )
+    parser.add_argument('-t', '--type',
+        help='Path Type',
+    )
     parser.add_argument('-r', '--root_dir',
         help='root_dir of book, such as xxx/goxceed/v1.9-dev',
     )
@@ -344,6 +367,11 @@ def parse_options():
         type=str, 
         help='Is generator all *.md in Summary',
     )
+    parser.add_argument('-g', '--include', action='store_const', const = True,
+        default = False,
+        help='enable in include_summary'
+    )
+
 
     args = parser.parse_args()
 
@@ -361,9 +389,9 @@ def main():
     args = parse_options()
     if args.dir != None:
         now_dir = os.getcwd()
-        goxceed_path = args.dir
-        if not goxceed_path.startswith('/'):
-            goxceed_path = os.path.join(now_dir, args.dir)
+        doc_path = args.dir
+        if not doc_path.startswith('/'):
+            doc_path = os.path.join(now_dir, args.dir)
 
         link_path = args.link
         #if not link_path.startswith('/'):
@@ -371,58 +399,61 @@ def main():
 
         root_path = args.root_dir
         if root_path == None:
-            root_path = goxceed_path
+            root_path = doc_path
         elif not root_path.startswith('/'):
             root_path = os.path.join(now_dir, args.root_dir)
 
-        if os.path.basename(root_path) == 'doc':
-            root_path = re.sub('doc', '', root_path)
-        else:
-            root_path = re.sub('doc/', '', root_path)
+        if root_path != doc_path:
+            if os.path.basename(root_path) == 'doc':
+                root_path = re.sub('doc', '', root_path)
+            else:
+                root_path = re.sub('doc/', '', root_path)
 
 
-        path_type = 'all'
-        if goxceed_path != root_path:
-            path_type = 'part'
+        #path_type = 'all'
+        #if doc_path != root_path:
+        #    path_type = 'part'
+        enable_include_link = args.include
+        path_type = args.type
 
-        rel_path = os.path.relpath(goxceed_path, root_path)
+        rel_path = os.path.relpath(doc_path, root_path)
         if os.path.basename(rel_path) == 'doc':
             rel_path = re.sub('doc', '', rel_path)
         else:
             rel_path = re.sub('doc/', '', rel_path)
-        print('link_path : ' +  link_path)
-        print('root_path : ' +  root_path)
-        print('doc_path : ' +  goxceed_path)
-        print('rel_path : ' + rel_path)
 
-        goxceed_path = os.path.abspath(goxceed_path)
+        doc_path = os.path.abspath(doc_path)
         #outpath = os.path.join(now_dir, link_path, '_gen_output', rel_path)
         if not link_path.startswith('/'):
             outpath = os.path.join(now_dir, link_path, rel_path)
         else:
             outpath = os.path.join(link_path, rel_path)
-        os.chdir(goxceed_path)
-        genxml = GenXML(goxceed_path, outpath, path_type = path_type)
+        os.chdir(doc_path)
+        #print('link_path : ' +  link_path)
+        #print('root_path : ' +  root_path)
+        #print('doc_path : ' +  doc_path)
+        #print('rel_path : ' + rel_path)
+        #print('outpath : ' + outpath)
+        genxml = GenXML(doc_path, outpath, path_type = path_type)
         cfgdirs = genxml.GetXml()
-        #sys.exit()
         bookoutpath = os.path.join(outpath, 'book')
         print(bookoutpath)
-        genmd = GenMD(goxceed_path, bookoutpath, cfgdirs, outpath+'/XML', \
-                path_type, link_path, now_dir, rel_path)
+        genmd = GenMD(doc_path, bookoutpath, cfgdirs, outpath+'/XML', \
+                path_type, link_path, now_dir, rel_path, enable_include_link)
         genmd.GenMD('yes')
         genmd.modify_summary_path()
         genmd.check_file('SUMMARY.md')
         genmd.check_file('include_summary.md')
         genmd.check_file('readme.md')
     elif args.input != None:
-        goxceed_path = args.input
+        doc_path = args.input
         is_server = args.server
         allgenerator = args.allgenerator
-        goxceed_path = os.path.abspath(goxceed_path)
-        outpath = goxceed_path
+        doc_path = os.path.abspath(doc_path)
+        outpath = doc_path
         outpath = os.path.join(outpath, 'docs')
-        os.chdir(goxceed_path)
-        genxml = GenXML(goxceed_path, outpath, is_server)
+        os.chdir(doc_path)
+        genxml = GenXML(doc_path, outpath, is_server)
         modules, cfgdirs = genxml.GetXml2()
         if is_server == 'yes':
             for cfgdir in cfgdirs:
@@ -434,7 +465,7 @@ def main():
         #    for cfgdir in cfgdirs:
         #        os.remove(os.path.join(cfgdir,'doxygen.cfg'))
         bookoutpath = os.path.join(outpath, 'book')
-        genmd = GenMD(goxceed_path, bookoutpath, cfgdirs, outpath+'/XML' )
+        genmd = GenMD(doc_path, bookoutpath, cfgdirs, outpath+'/XML' )
         genmd.GenMD(allgenerator)
 
 
@@ -442,12 +473,12 @@ if __name__ == "__main__":
     main()
 
 
-#for dirpath,dirnames,filenames in os.walk(goxceed_path+'/gxtest/doc'):
+#for dirpath,dirnames,filenames in os.walk(doc_path+'/gxtest/doc'):
 #    print(dirpath, dirnames, filenames)
-#print(os.listdir(goxceed_path))
+#print(os.listdir(doc_path))
 #
 #print(os.getcwd())
 ##os.chdir()
-#print(goxceed_path)
+#print(doc_path)
 
 
