@@ -50,6 +50,9 @@ ADDITIONAL_FILES = {
 }
 
 def generate_link(name, url) -> str:
+    '''
+    in modify summary
+    '''
     return '* [' + name + '](' + url + ')\n'
 
 class Generator:
@@ -338,6 +341,7 @@ class Generator:
             'member_definition_template': self.member_definition_template,
             'member_table_template': self.member_table_template
         }
+        
         self._render(self.function_template, path, data)
 
         if node.is_language or node.is_group or node.is_file or node.is_dir:
