@@ -13,12 +13,16 @@ from doxybook.property import Property
 
 class Node:
     _output_dir = ''
-    def __init__(self, xml_file: str, xml: Element, cache: Cache, parser: XmlParser, parent: 'Node', refid: str = None, position: str = None ):
+    def __init__(self, xml_file: str, xml: Element, cache: Cache, parser: XmlParser, \
+            parent: 'Node', refid: str = None, position: str = None , \
+            doc_type = 'all', rel_path = ''):
         self._children: ['Node'] = []
         self._cache: Cache = cache
         self._parser: XmlParser = parser
         self._parent = parent
         self._position = position
+        self.doc_type = doc_type
+        self.rel_path = rel_path
 
         if xml_file == 'root':
             self._refid = 'root'
@@ -114,7 +118,8 @@ class Node:
                     continue
                 except:
                     pass
-            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self)
+            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self, \
+                    doc_type = self.doc_type, rel_path = self.rel_path)
             child._visibility = Visibility.PUBLIC
             self.add_child(child)
 
@@ -133,9 +138,11 @@ class Node:
                     pass
 
             try:
-                child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self)
+                child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self, 
+                    doc_type = self.doc_type, rel_path = self.rel_path)
             except FileNotFoundError as e:
-                child = Node(os.path.join(self._dirname, refid + '.xml'), Element('compounddef'), self._cache, self._parser, self, refid=refid)
+                child = Node(os.path.join(self._dirname, refid + '.xml'), Element('compounddef'), self._cache, self._parser, self, refid=refid, \
+                    doc_type = self.doc_type, rel_path = self.rel_path)
                 child._name = innerclass.text
             child._visibility = prot
             self.add_child(child)
@@ -150,7 +157,8 @@ class Node:
                 except:
                     pass
 
-            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self)
+            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self, \
+                    doc_type = self.doc_type, rel_path = self.rel_path)
             child._visibility = Visibility.PUBLIC
             self.add_child(child)
 
@@ -164,7 +172,8 @@ class Node:
                 except:
                     pass
 
-            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self)
+            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self, \
+                    doc_type = self.doc_type, rel_path = self.rel_path)
             child._visibility = Visibility.PUBLIC
             self.add_child(child)
 
@@ -179,7 +188,8 @@ class Node:
                 except:
                     pass
 
-            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self)
+            child = Node(os.path.join(self._dirname, refid + '.xml'), None, self._cache, self._parser, self, \
+                    doc_type = self.doc_type, rel_path = self.rel_path)
             child._visibility = Visibility.PUBLIC
             self.add_child(child)
 
@@ -196,7 +206,8 @@ class Node:
                         except:
                             pass
                     child = Node(None, memberdef, self._cache, self._parser,
-                            self, position = self._position)
+                            self, position = self._position, \
+                            doc_type = self.doc_type, rel_path = self.rel_path)
                     #if child._kind == Kind.ENUM:
                     #    print('aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa')
                     #    print(child.name)
@@ -748,7 +759,8 @@ class Node:
             details = re.sub('gxdocref \[','[',details)
             return details
        # name = self._name.replace('_', '\\_')
-        refs = re.findall('gxdocref +[\S]+', details)
+        #refs = re.findall('gxdocref +[\S]+', details)
+        refs = re.findall('gxdocref +[^ \n\r\t\v\f、。，；,.;]+', details)
         if refs:
             for ref in refs:
                 refname = re.sub('gxdocref[\s]+', '', ref)
@@ -757,8 +769,15 @@ class Node:
                 if not node:
                     continue
                 refname = refname.replace('_','\\\\_')
-                details = re.sub('gxdocref *'+refname,'[**'+refname+'**]('+
-                        node.url + ')', details)
+                #details = re.sub('gxdocref *'+refname,'[**'+refname+'**]('+
+                #        node.url + ')', details)
+                if self.doc_type == 'all':
+                    details = re.sub('gxdocref *'+refname,'[**'+refname+'**]('+
+                            node.url + ')', details)
+                else:
+                #elif self.doc_type == 'part':
+                    details = re.sub('gxdocref *'+refname,'[**'+refname+'**](/'+ \
+                            self.rel_path + '/book' + node.url + ')', details)
         return details
 
     @property
@@ -771,7 +790,8 @@ class Node:
         if re.findall('gxdocref_', brief):
             brief = re.sub('gxdocref_', 'gxdocref', brief)
             brief = re.sub('(gxdocref) +\[_\*\*(.+)\*\*_\] *\(.+\) _','\g<1> \g<2> ',brief)
-        refs = re.findall('gxdocref +[\S]+', brief)
+        #refs = re.findall('gxdocref +[\S]+', brief)
+        refs = re.findall('gxdocref +[^ \n\r\t\v\f、。，；,.;]+', brief)
         if refs:
             for ref in refs:
                 refname = re.sub('gxdocref[\s]+', '', ref)
@@ -782,8 +802,15 @@ class Node:
                 if not node:
                     continue
                 refname = refname.replace('_','\\\\_')
-                brief = re.sub('gxdocref *'+refname,'[**'+refname+'**]('+
-                        node.url + ')', brief)
+                if self.doc_type == 'all':
+                    brief = re.sub('gxdocref *'+refname,'[**'+refname+'**]('+
+                            node.url + ')', brief)
+                else:
+                #elif self.doc_type == 'part':
+                    #tmp = node.url.split('/')
+                    #tmp.insert(-1, 'book')
+                    brief = re.sub('gxdocref *'+refname,'[**'+refname+'**](/' + \
+                            self.rel_path + '/book' + node.url + ')', brief)
         return brief
 
     @property
