@@ -9,7 +9,6 @@ TEMPLATE = """
 {%- endif -%}
 
 {% if node.has_details -%}
-"\n"
 {{node.details}}
 {%- endif -%}
 
@@ -17,3 +16,4 @@ TEMPLATE = """
 Implements [*{{node.reimplements.name_long}}*]({{node.reimplements.url}})
 {% endif %}
 """
+#"\n"
